@@ -234,7 +234,9 @@ class AndroidTesterCommandRunner(NetworkCommandRunner):
         if self._client.target_device.config.android_adb_over_tcp:
             self._setup_adb_over_tcp()
         elif self._client.target_device.config.android_adb_over_usb:
-            self._setup_adb_over_usb()
+            # Nothing to do here. If in the future we decide to dynamically
+            # determine a usb serial number, this would be the place to do it.
+            pass
         else:
             raise CriticalError('ADB not configured for TCP or USB')
 
@@ -257,12 +259,6 @@ class AndroidTesterCommandRunner(NetworkCommandRunner):
         self.android_adb_over_tcp_connect()
         self.wait_until_attached()
 
-    def _setup_adb_over_usb(self):
-        self.run(
-            'getprop ro.serialno',
-            response=self._client.target_device.config.android_serialno_patterns)
-        self.dev_name = self.match.group(0)
-
     def disconnect(self):
         if self._client.target_device.config.android_adb_over_tcp:
             self.android_adb_over_tcp_disconnect()
@@ -284,6 +280,11 @@ class AndroidTesterCommandRunner(NetworkCommandRunner):
         else:
             raise ADBConnectError(('Failed to connected to device with'
                                    ' command:%s') % cmd)
+        # Users can define 'android_adb_over_tcp' dynamically, so we must set
+        # the adb_command dynamically as well. This also allows us to re-use
+        # the existing code in the fastboot classes seamlessly.
+        self._client.target_device.config.adb_command = \
+            'adb -s %s:%s' % (dev_ip, adb_port)
 
     def android_adb_over_tcp_disconnect(self):
         dev_ip = self.dev_ip
@@ -314,7 +315,7 @@ class AndroidTesterCommandRunner(NetworkCommandRunner):
             logging.warning(traceback.format_exc())
             return None
         ip_pattern1 = "%s: ip (\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}) mask" % nic_name
-        ip_pattern2 = "inet addr:(\d?\d?\d?\.\d?\d?\d?\.\d?\d?\d?\.\d?\d?\d?)"
+        ip_pattern2 = "inet addr:(\d?\d?\d?\.\d?\d?\d?\.\d?\d?\d?\.\d?\d?\d?) +Bcast:"
         try:
             self.run("ifconfig %s" % nic_name,
                      [ip_pattern1, ip_pattern2, pexpect.EOF],
@@ -322,7 +323,8 @@ class AndroidTesterCommandRunner(NetworkCommandRunner):
         except Exception as e:
             raise NetworkError("ifconfig can not match ip pattern for %s:%s" % (nic_name, e))
 
-        if self.match_id == 0:
+        # keep the match_id range in line with the number of patterns.
+        if self.match_id in [0, 1]:
             match_group = self.match.groups()
             if len(match_group) > 0:
                 return match_group[0]
