@@ -116,8 +116,8 @@ class LavaContext(object):
 
     @property
     def any_host_bundles(self):
-        return (self._host_result_dir is not None
-                and len(os.listdir(self._host_result_dir)) > 0)
+        return (self._host_result_dir is not None and
+                len(os.listdir(self._host_result_dir)) > 0)
 
     @property
     def host_result_dir(self):
