@@ -63,7 +63,7 @@ class RetryAction(Action):
                 self.retries += 1
                 self.errors = "%s failed: %d of %d attempts. '%s'" % (self.name, self.retries, self.max_retries, exc)
                 if self.timeout:
-                    self.logger.warning(" %s: timeout. %s seconds" % (self.timeout.name, int(self.timeout.duration)))
+                    self.logger.warning("%s: timeout reached. %s seconds" % (self.timeout.name, int(self.timeout.duration)))
                 time.sleep(self.sleep)
         if not self.valid:
             self.errors = "%s retries failed for %s" % (self.retries, self.name)
