@@ -26,6 +26,7 @@ from lava_dispatcher.pipeline.action import (
     Pipeline,
     Action,
     Timeout,
+    JobError,
 )
 from lava_dispatcher.pipeline.logical import (
     Deployment,
@@ -109,10 +110,18 @@ class JobParser(object):
                 job.timeout = Timeout(data['job_name'], duration)
             if 'action' in data['timeouts']:
                 self.context['default_action_duration'] = Timeout.parse(data['timeouts']['action'])
+            if 'connection' in data['timeouts']:
+                self.context['default_connection_duration'] = Timeout.parse(data['timeouts']['connection'])
             if 'test' in data['timeouts']:
                 self.context['default_test_duration'] = Timeout.parse(data['timeouts']['test'])
 
-    # FIXME: add a validate() function which checks against a Schema as a completely separate step.
+    def _map_context_defaults(self):
+        return {
+            'default_action_timeout': self.context['default_action_duration'],
+            'default_test_timeout': self.context['default_test_duration'],
+            'default_connection_timeout': self.context['default_connection_duration']
+        }
+
     # pylint: disable=too-many-locals,too-many-statements
     def parse(self, content, device, job_id, socket_addr, output_dir=None,
               env_dut=None):
@@ -123,14 +132,16 @@ class JobParser(object):
 
         self.context['default_action_duration'] = Timeout.default_duration()
         self.context['default_test_duration'] = Timeout.default_duration()
+        self.context['default_connection_duration'] = Timeout.default_duration()
         job = Job(job_id, socket_addr, data)
         counts = {}
         job.device = device
         job.parameters['output_dir'] = output_dir
         job.parameters['env_dut'] = env_dut
         job.parameters['target'] = device.target
-        for instance in Protocol.select_all(job.parameters):
-            job.protocols.append(instance(job.parameters))
+        level_tuple = Protocol.select_all(job.parameters)
+        # sort the list of protocol objects by the protocol class level.
+        job.protocols = [item[0](job.parameters) for item in sorted(level_tuple, key=lambda level_tuple: level_tuple[1])]
         pipeline = Pipeline(job=job)
         self._timeouts(data, job)
 
@@ -140,8 +151,7 @@ class JobParser(object):
             action_data.pop('yaml_line', None)
             for name in action_data:
                 if type(action_data[name]) is dict:  # FIXME: commands are not fully implemented & may produce a list
-                    action_data[name]['default_action_timeout'] = self.context['default_action_duration']
-                    action_data[name]['default_test_timeout'] = self.context['default_test_duration']
+                    action_data[name].update(self._map_context_defaults())
                 counts.setdefault(name, 1)
                 if name == 'deploy' or name == 'boot' or name == 'test':
                     # reset the context before adding a second deployment and again before third etc.
@@ -177,11 +187,22 @@ class JobParser(object):
                             action.parameters = param
                     action.summary = name
                     action.timeout = Timeout(action.name, self.context['default_action_duration'])
+                    action.connection_timeout = Timeout(action.name, self.context['default_connection_duration'])
                     pipeline.add_action(action)
                 counts[name] += 1
 
         # there's always going to need to be a finalize_process action
-        pipeline.add_action(FinalizeAction())
+        finalize = FinalizeAction()
+        pipeline.add_action(finalize)
+        finalize.populate(self._map_context_defaults())
         data['output_dir'] = output_dir
         job.set_pipeline(pipeline)
+        if 'compatibility' in data:
+            try:
+                job_c = int(job.compatibility)
+                data_c = int(data['compatibility'])
+            except ValueError as exc:
+                raise JobError('invalid compatibility value: %s' % exc)
+            if job_c < data_c:
+                raise JobError('Dispatcher unable to meet job compatibility requirement. %d > %d' % (job_c, data_c))
         return job
