@@ -91,7 +91,7 @@ def mkdtemp(basedir='/tmp'):
 
     d = tempfile.mkdtemp(dir=basedir)
     atexit.register(rmtree, d)
-    os.chmod(d, 0755)
+    os.chmod(d, 0o755)
     return d
 
 
